@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009, 2010, 2017  Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (C) 2009, 2010, 2016  Internet Systems Consortium, Inc. ("ISC")
  *
  * Permission to use, copy, modify, and/or distribute this software for any
  * purpose with or without fee is hereby granted, provided that the above
@@ -14,10 +14,13 @@
  * PERFORMANCE OF THIS SOFTWARE.
  */
 
+/* $Id: tsec.c,v 1.7 2010/12/09 00:54:34 marka Exp $ */
+
 #include <config.h>
 
 #include <isc/mem.h>
-#include <isc/util.h>
+
+#include <pk11/site.h>
 
 #include <dns/tsec.h>
 #include <dns/tsig.h>
@@ -64,9 +67,11 @@ dns_tsec_create(isc_mem_t *mctx, dns_tsectype_t type, dst_key_t *key,
 	switch (type) {
 	case dns_tsectype_tsig:
 		switch (dst_key_alg(key)) {
+#ifndef PK11_MD5_DISABLE
 		case DST_ALG_HMACMD5:
 			algname = dns_tsig_hmacmd5_name;
 			break;
+#endif
 		case DST_ALG_HMACSHA1:
 			algname = dns_tsig_hmacsha1_name;
 			break;
